Usage
=====
PDFstream can be used in command line interface (CLI) or in python (e. g. ipython, jupyter notebook). Currently,
it is only applicable to data from filesystems. The next step is to link the processor units to the
databroker so that it can process the data from an event stream.


.. toctree::
   :maxdepth: 1

   cli
   python
